"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _changeCase = require("change-case");

var _actionPreflightCheck = _interopRequireDefault(require("./utils/actionPreflightCheck"));

var _isModularType = _interopRequireDefault(require("./utils/isModularType"));

var _execSync = _interopRequireDefault(require("./utils/execSync"));

var _getLocation = _interopRequireDefault(require("./utils/getLocation"));

var _stageView = _interopRequireDefault(require("./utils/stageView"));

var _getModularRoot = _interopRequireDefault(require("./utils/getModularRoot"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function start(target) {
  const targetPath = await (0, _getLocation.default)(target);

  if ((0, _isModularType.default)(targetPath, 'package')) {
    throw new Error(`The package at ${targetPath} is not a valid modular app or view.`);
  }
  /**
   * If we're trying to start a view then we first need to stage out the
   * view into an 'app' directory which can be built.
   */


  let startPath;

  if ((0, _isModularType.default)(targetPath, 'view')) {
    startPath = (0, _stageView.default)(target);
  } else {
    startPath = targetPath;
  }

  const startScript = require.resolve('modular-scripts/react-scripts/scripts/start.js');

  const modularRoot = (0, _getModularRoot.default)();
  const targetName = (0, _changeCase.paramCase)(target);
  (0, _execSync.default)('node', [startScript], {
    cwd: startPath,
    log: false,
    // @ts-ignore
    env: {
      MODULAR_ROOT: modularRoot,
      MODULAR_PACKAGE: target,
      MODULAR_PACKAGE_NAME: targetName
    }
  });
  return Promise.resolve();
}

var _default = (0, _actionPreflightCheck.default)(start);

exports.default = _default;