"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.log = log;
exports.warn = warn;
exports.error = error;
exports.debug = debug;

var _chalk = _interopRequireDefault(require("chalk"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const prefix = '[modular] ';
const DEBUG = process.env.MODULAR_LOGGER_DEBUG || process.argv.includes('--verbose');
const SILENT = process.env.MODULAR_LOGGER_MUTE;

function printStdErr(x) {
  if (SILENT) {
    return;
  }

  x.split('\n').forEach(l => {
    process.stderr.write(_chalk.default.dim(prefix) + l + '\n');
  });
}

function printStdOut(x) {
  if (SILENT) {
    return;
  }

  x.split('\n').forEach(l => {
    process.stdout.write(_chalk.default.dim(prefix) + l + '\n');
  });
}

function log(...x) {
  printStdOut(x.join(' '));
}

function warn(...x) {
  printStdErr(_chalk.default.yellow(x.join(' ')));
}

function error(...x) {
  printStdErr(_chalk.default.red(x.join(' ')));
}

function debug(...x) {
  if (DEBUG) {
    log('[debug]', ...x);
  }
}